@@ -9,3 +9,9 @@ sort.gtf <- function(input, output) {
 	system(paste("java -cp  '", chipster.module.path, "/../../../shared/lib/*' fi.csc.chipster.tools.ngs.SortGtf ", input, " ", output, sep = ""))
 }
 
+# Adds "chr" to the beginning of each line that starts with a number or with X, Y, Z, W or M
+#
+addChrToGtf <- function(input, output){
+	awk.command <- paste("awk '{ if ($1 ~ /^[0-9,X,Y,Z,W,M]/) {print \"chr\"$0} else {print $0} }'", input, ">", output)
+	system(awk.command)
+}
\ No newline at end of file
