@@ -5,37 +5,39 @@
 # OUTPUT OPTIONAL RSeQC.junctionSaturation_plot.pdf
 # OUTPUT OPTIONAL RSeQC.splice_events.pdf
 # OUTPUT OPTIONAL RSeQC.splice_junction.pdf
-# OUTPUT OPTIONAL RSeQC.RKPM_saturation.pdf
+# OUTPUT OPTIONAL RSeQC.RPKM_saturation.pdf
 # OUTPUT OPTIONAL RSeQC.bamStat.txt
 # OUTPUT OPTIONAL RSeQC.inner_distance_plot.pdf
 # PARAMETER OPTIONAL paired: "Generate inner distance plot" TYPE [yes, no] DEFAULT no (Calculate the inner distance (or insert size\) between two paired RNA reads. The distance is the mRNA length between two paired fragments.)
 
 # AMS 09.01.2014
 # AMS 23.05.2014 added inner distance plot
+# AMS 03.12.2014 improved error handling for the plots
 
 # geneBody_coverage
 binary <- c(file.path(chipster.tools.path, "RSeQC", "scripts", "geneBody_coverage.py"))
 command <- paste(binary, "-i alignment_file -r reference_file -o RSeQC")
 system(command)
-source("RSeQC.geneBodyCoverage_plot.r")
+try(source("RSeQC.geneBodyCoverage_plot.r"), silent=TRUE)
 
 # junction_saturation
 binary <- c(file.path(chipster.tools.path, "RSeQC", "scripts", "junction_saturation.py"))
 command <- paste(binary, "-i alignment_file -r reference_file -o RSeQC")
 system(command)
-source("RSeQC.junctionSaturation_plot.r")
+try(source("RSeQC.junctionSaturation_plot.r"), silent=TRUE)
 
 # junction_annotation
 binary <- c(file.path(chipster.tools.path, "RSeQC", "scripts", "junction_annotation.py"))
 command <- paste(binary, "-i alignment_file -r reference_file -o RSeQC")
 system(command)
-source("RSeQC.junction_plot.r")
+try(source("RSeQC.junction_plot.r"), silent=TRUE)
 
 #RPKM_saturation
 binary <- c(file.path(chipster.tools.path, "RSeQC", "scripts", "RPKM_saturation.py"))
 command <- paste(binary, "-i alignment_file -r reference_file -o RSeQC")
 system(command)
-source("RSeQC.saturation.r")
+try(source("RSeQC.saturation.r"), silent=TRUE)
+system("mv RSeQC.saturation.pdf RSeQC.RPKM_saturation.pdf")
 
 # bam_stat
 binary <- c(file.path(chipster.tools.path, "RSeQC", "scripts", "bam_stat.py"))
@@ -47,8 +49,5 @@ if (paired == "yes"){
 	binary <- c(file.path(chipster.tools.path, "RSeQC", "scripts", "inner_distance.py"))
 	command <- paste(binary, "-i alignment_file -r reference_file -o RSeQC")
 	system(command)
-	source("RSeQC.inner_distance_plot.r")	
+	try(source("RSeQC.inner_distance_plot.r"), silent=TRUE)	
 }
-
-#system("ls > results.txt")
-system("mv RSeQC.saturation.pdf RSeQC.RKPM_saturation.pdf")
\ No newline at end of file
