@@ -2,13 +2,13 @@
 # INPUT reads1.fq: "Read file 1" TYPE GENERIC
 # INPUT reads2.fq: "Read file 2 with mates in matching order" TYPE GENERIC
 # INPUT OPTIONAL genes.gtf: "Optional GTF file" TYPE GENERIC
-# OUTPUT tophat.bam
-# OUTPUT tophat.bam.bai
+# OUTPUT OPTIONAL tophat.bam
+# OUTPUT OPTIONAL tophat.bam.bai
 # OUTPUT OPTIONAL junctions.bed
 # OUTPUT OPTIONAL insertions.bed
 # OUTPUT OPTIONAL deletions.bed
 # OUTPUT OPTIONAL tophat-summary.txt
-# PARAMETER genome: "Genome" TYPE [hg19: "Human genome (hg19\)", mm10: "Mouse genome (mm10\)", Rattus_norvegicus.Rnor_5.0.70.dna.toplevel: "Rat genome (rn5\)", rn4: "Rat genome (rn4\)", Halorubrum_lacusprofundi_ATCC_49239: "Halorubrum lacusprofundi ATCC 49239 genome", Canis_familiaris.CanFam3.1.71.dna.toplevel: "Dog genome (Ensembl canFam3\)", Sus_scrofa.Sscrofa10.2.69.dna.toplevel: "Pig (sus_scrofa10.2.69\)",  Gasterosteus_aculeatus.BROADS1.71.dna.toplevel: "Gasterosteus aculeatus genome (BROADS1.71\)", Drosophila_melanogaster.BDGP5.73.dna.toplevel: "Drosophila_melanogaster (BDGP5.73\)", athaliana.TAIR10: "A. thaliana genome (TAIR10\)", ovis_aries_texel: "Sheep genome (oar3.1\)", Schizosaccharomyces_pombe.ASM294v2.22.dna.toplevel: "Schizosaccharomyces pombe (ASM294v2.22\)"] DEFAULT hg19 (Genome or transcriptome that you would like to align your reads against.)
+# PARAMETER organism: "Genome or transcriptome" TYPE [Arabidopsis_thaliana.TAIR10.23, Bos_taurus.UMD3.1, Canis_familiaris.CanFam3.1, Drosophila_melanogaster.BDGP5, Gallus_gallus.Galgal4, Gasterosteus_aculeatus.BROADS1, Halorubrum_lacusprofundi_atcc_49239.GCA_000022205.1.23, Homo_sapiens.GRCh37.75, Homo_sapiens.GRCh38, Mus_musculus.GRCm38, Ovis_aries.Oar_v3.1, Rattus_norvegicus.Rnor_5.0, Schizosaccharomyces_pombe.ASM294v2.23, Sus_scrofa.Sscrofa10.2, Vitis_vinifera.IGGP_12x.23, Yersinia_enterocolitica_subsp_palearctica_y11.GCA_000253175.1.23] DEFAULT Homo_sapiens.GRCh38 (Genome or transcriptome that you would like to align your reads against.)
 # PARAMETER OPTIONAL use.gtf: "Use annotation GTF" TYPE [yes, no] DEFAULT yes (If this option is provided, TopHat will extract the transcript sequences and use Bowtie to align reads to this virtual transcriptome first. Only the reads that do not fully map to the transcriptome will then be mapped on the genome. The reads that did map on the transcriptome will be converted to genomic mappings (spliced as needed\) and merged with the novel mappings and junctions in the final TopHat output. If no GTF file is provided by user, internal annotation file will be used if available. Internal annotation is provided for human, mouse, rat, dog and fruitfly.)
 # PARAMETER OPTIONAL no.novel.juncs: "When GTF file is used, ignore novel junctions" TYPE [yes, no] DEFAULT no (Only look for reads across junctions indicated in the supplied GTF file.)
 # PARAMETER OPTIONAL quality.format: "Base quality encoding used" TYPE [sanger: "Sanger - Phred+33", phred64: "Phred+64"] DEFAULT sanger (Quality encoding used in the fastq file.)
@@ -20,7 +20,8 @@
 # PARAMETER OPTIONAL splice.mismatches: "Maximum number of mismatches allowed in the anchor" TYPE INTEGER FROM 0 TO 2 DEFAULT 0 (The maximum number of mismatches that may appear in the anchor region of a spliced alignment.)
 # PARAMETER OPTIONAL min.intron.length: "Minimum intron length" TYPE INTEGER FROM 10 TO 1000 DEFAULT 70 (TopHat2 will ignore donor-acceptor pairs closer than this many bases apart.)
 # PARAMETER OPTIONAL max.intron.length: "Maximum intron length" TYPE INTEGER FROM 1000 TO 1000000 DEFAULT 500000 (TopHat2 will ignore donor-acceptor pairs farther than this many bases apart, except when such a pair is supported by a split segment alignment of a long read.)
-
+# PARAMETER OPTIONAL no.discordant: "Report only concordant alignments" TYPE [yes, no] DEFAULT yes (Report only concordant mappings.) 
+# PARAMETER OPTIONAL no.mixed: "Report only paired alignments" TYPE [yes, no] DEFAULT yes (Only report read alignments if both reads in a pair can be mapped.)
 
 # EK 17.4.2012 added -G and -g options
 # MG 24.4.2012 added ability to use gtf files from Chipster server
@@ -31,6 +32,8 @@
 # AMS 11.11.2013 added thread support
 # AMS 3.1.2014 added transcriptome index for human
 # EK 3.1.2014 added alignment summary to output, added quality and mismatch parameter
+# EK 3.6.2014 rn4 commented out
+# AMS 04.07.2014 New genome/gtf/index locations & names
 
 # OUTPUT OPTIONAL tophat2.log
 
@@ -47,7 +50,8 @@ tophat.binary <- c(file.path(chipster.tools.path, "tophat2", "tophat2"))
 path.bowtie <- c(file.path(chipster.tools.path, "bowtie2"))
 path.samtools <- c(file.path(chipster.tools.path, "samtools"))
 set.path <-paste(sep="", "PATH=", path.bowtie, ":", path.samtools, ":$PATH")
-path.bowtie.index <- c(file.path(path.bowtie, "indexes", genome))
+path.bowtie.index <- c(file.path(chipster.tools.path, "genomes", "indexes", "bowtie2", organism))
+path.tophat.index <- c(file.path(chipster.tools.path, "genomes", "indexes", "tophat2", organism))
 
 # command start
 command.start <- paste("bash -c '", set.path, tophat.binary)
@@ -60,71 +64,36 @@ if ( quality.format == "phred64") {
 	command.parameters <- paste(command.parameters, "--phred64-quals")
 }
 
-# optional GTF command, if a GTF file has been provided by user
-command.gtf <- ""
-input_files <- dir()
-is_gtf <- (length(grep("genes.gtf", input_files))>0)
-if (is_gtf) {
-	if (no.novel.juncs == "yes") {
-		command.gtf <- paste("-G", "genes.gtf", "--no-novel-juncs")
-	} else {
-		command.gtf <- paste("-G", "genes.gtf")
-	}
+if (no.discordant == "yes"){
+	command.parameters <- paste(command.parameters, "--no-discordant")
 }
 
-# optional GTF command, if a GTF file has NOT been provided by user
-# BUT is avaliable from Chipster server OR transkriptome index is available
-genome_available <- FALSE
-if (genome == "hg19" ||	genome == "mm10" || genome == "rn4" || genome == "Rattus_norvegicus.Rnor_5.0.70.dna.toplevel" || genome == "Canis_familiaris.CanFam3.1.71.dna.toplevel" ||genome == "Drosophila_melanogaster.BDGP5.73.dna.toplevel") genome_available <- TRUE
-if (!is_gtf && genome_available) {
+if (no.mixed == "yes"){
+	command.parameters <- paste(command.parameters, "--no-mixed")
+}
 
-	# annotation file setup
-	if (genome == "hg19") {
-		annotation.file <- c(file.path(path.bowtie, "indexes", "hg19.ti"))
-		ti.command <- c("--transcriptome-index=", annotation.file)
-		annotation.command <- paste(ti.command, collapse = '')		
+# Options --no-novel-juncs and --transcriptome-idex are only valid when -G (use.gtf) option is selected
+if (use.gtf == "yes") {
+	if (file.exists("annotation.gtf")){
+		# If user has provided a gtf we use that
+		annotation.file <- "annotation.gtf"
+	}else{
+		# If not, we use the internal one.
+		annotation.file <- file.path(chipster.tools.path, "genomes", "gtf", paste(organism, "*.gtf" ,sep="" ,collapse=""))
 	}
-	if (genome == "mm10") {
-		annotation.file <- c(file.path(chipster.tools.path, "genomes", "gtf", "Mus_musculus.GRCm38.68.chr.gtf"))
-		annotation.command <- paste("-G", annotation.file)
-	}
-		if (genome == "rn4") {
-		annotation.file <- c(file.path(chipster.tools.path, "genomes", "gtf", "Rattus_norvegicus.RGSC3.4.62.chr.gtf"))
-		annotation.command <- paste("-G", annotation.file)
-	}
-	if (genome == "Rattus_norvegicus.Rnor_5.0.70.dna.toplevel") {
-		annotation.file <- c(file.path(chipster.tools.path, "genomes", "gtf", "Rattus_norvegicus.Rnor_5.0.70.gtf"))
-		annotation.command <- paste("-G", annotation.file)
-	}
-	if (genome == "Canis_familiaris.CanFam3.1.71.dna.toplevel") {
-		annotation.file <- c(file.path(chipster.tools.path, "genomes", "gtf", "Canis_familiaris.CanFam3.1.71.gtf"))
-		annotation.command <- paste("-G", annotation.file)
-	}	
-	if (genome == "Drosophila_melanogaster.BDGP5.73.dna.toplevel") {
-		annotation.file <- c(file.path(chipster.tools.path, "genomes", "gtf", "Drosophila_melanogaster.BDGP5.73.gtf"))
-		annotation.command <- paste("-G", annotation.file)
-	}
-	if (genome == "Schizosaccharomyces_pombe.ASM294v2.22.dna.toplevel") {
-		annotation.file <- c(file.path(chipster.tools.path, "genomes", "gtf", "Schizosaccharomyces_pombe.ASM294v2.22.gtf"))
-		annotation.command <- paste("-G", annotation.file)
-	}
-	
+	command.parameters <- paste(command.parameters, "-G", annotation.file)
 	if (no.novel.juncs == "yes") {
-		command.gtf <- paste(annotation.command, "--no-novel-juncs")
-	} else {
-		command.gtf <- paste(annotation.command)
+		command.parameters <- paste(command.parameters, "--no-novel-juncs")
 	}
+	command.parameters <- paste(command.parameters, "--transcriptome-index", path.tophat.index)
 }
 
 # command ending
 command.end <- paste(path.bowtie.index, "reads1.fq reads2.fq >> tophat2.log '")
 
 # run tophat
-if (use.gtf == "yes"){ 
-	command <- paste(command.start, command.parameters, command.gtf, command.end)
-}else{
-	command <- paste(command.start, command.parameters, command.end)
-}
+command <- paste(command.start, command.parameters, command.end)
+
 echo.command <- paste("echo '",command ,"' > tophat2.log " )
 system(echo.command)
 #stop(paste('CHIPSTER-NOTE: ', command))
@@ -156,27 +125,32 @@ system(echo.command)
 #system("sleep 120")
 #stop(paste('CHIPSTER-NOTE: ', size))
 
-
-
-if (size > 100){	
-	bed <- read.table(file="junctions.u.bed", skip=1, sep="\t")
-	colnames(bed)[1:2] <- c("chr", "start")
-	sorted.bed <- sort.bed(bed)
-	write.table(sorted.bed, file="junctions.bed", sep="\t", row.names=F, col.names=F, quote=F)
+if (file.exists("junctions.u.bed")){
+	size <- file.info("junctions.u.bed")$size
+	if (size > 100){	
+		bed <- read.table(file="junctions.u.bed", skip=1, sep="\t")
+		colnames(bed)[1:2] <- c("chr", "start")
+		sorted.bed <- sort.bed(bed)
+		write.table(sorted.bed, file="junctions.bed", sep="\t", row.names=F, col.names=F, quote=F)
+	}	
 }
 
-size <- file.info("insertions.u.bed")$size
-if (size > 100){
-	bed <- read.table(file="insertions.u.bed", skip=1, sep="\t")
-	colnames(bed)[1:2] <- c("chr", "start")
-	sorted.bed <- sort.bed(bed)
-	write.table(sorted.bed, file="insertions.bed", sep="\t", row.names=F, col.names=F, quote=F)
+if (file.exists("insertions.u.bed")){
+	size <- file.info("insertions.u.bed")$size
+	if (size > 100){
+		bed <- read.table(file="insertions.u.bed", skip=1, sep="\t")
+		colnames(bed)[1:2] <- c("chr", "start")
+		sorted.bed <- sort.bed(bed)
+		write.table(sorted.bed, file="insertions.bed", sep="\t", row.names=F, col.names=F, quote=F)
+	}
 }
 
-size <- file.info("deletions.u.bed")$size
-if (size > 100){
-	bed <- read.table(file="deletions.u.bed", skip=1, sep="\t")
-	colnames(bed)[1:2] <- c("chr", "start")
-	sorted.bed <- sort.bed(bed)
-	write.table(sorted.bed, file="deletions.bed", sep="\t", row.names=F, col.names=F, quote=F)
+if (file.exists("insertions.u.bed")){
+	size <- file.info("deletions.u.bed")$size
+	if (size > 100){
+		bed <- read.table(file="deletions.u.bed", skip=1, sep="\t")
+		colnames(bed)[1:2] <- c("chr", "start")
+		sorted.bed <- sort.bed(bed)
+		write.table(sorted.bed, file="deletions.bed", sep="\t", row.names=F, col.names=F, quote=F)
+	}
 }
